==> mktcenter-service-20240125-20240423.091204-2-sources.jar: com/bizvane/mktcenterservice/interfaces/ActivityPrizeServiceWX.java <==
package com.bizvane.mktcenterservice.interfaces;

import com.bizvane.mktcenterservice.models.bo.MktActivityPrizeRecordBO;
import com.bizvane.mktcenterservice.models.po.MktActivityPrizePOWithBLOBs;
import com.bizvane.mktcenterservice.models.po.MktActivityPrizeRecordPO;
import com.bizvane.mktcenterservice.models.vo.ActivityPriceBO;
import com.bizvane.mktcenterservice.models.vo.MktActivityPrizeRecordVO;
import com.bizvane.mktcenterservice.models.vo.ProbabilityVO;
import com.bizvane.mktcenterservice.models.vo.mktp.PrizeRecordCommonRequestVO;
import com.bizvane.utils.responseinfo.ResponseData;

import java.text.ParseException;
import java.util.List;
import java.util.Map;

/**
 * Created by agan on 2018/12/19.
 */
public interface ActivityPrizeServiceWX {
    /**
     * 小程序获取中奖纪录 和中奖纪录轮播
     * @param po
     * @return
     */
    public ResponseData<List<MktActivityPrizeRecordPO>> getPrizeRecordList(MktActivityPrizeRecordPO po);

    /**
     * 小程序获取中奖纪录 和中奖纪录轮播-包含奖项图片
     * @param requestVO
     * @return
     */
    ResponseData getPrizeRecordListNew(PrizeRecordCommonRequestVO requestVO);

    /**
     * 获取抽奖活动规则
     * @return
     */
    public ResponseData<ActivityPriceBO> selectPrizeList(MktActivityPrizeRecordVO vo);

    /**
     * 执行抽奖活动
     * @param activePriceCode
     * @return
     */
    @Deprecated
    public ResponseData<Map> executeActivityPrize(String activePriceCode, String memberCode) throws ParseException;

    /**
     * 执行抽奖活动(新)
     * @param activePriceCode
     * @param memberCode
     * @return
     * @throws ParseException
     */
    ResponseData<Map> executeActivityPrizeNew(String activePriceCode, String memberCode, Long clientBaseInfoId) throws ParseException;

    public ResponseData<Map<String, Integer>> residueMemberNumber(ProbabilityVO vo) throws ParseException;

    /**
     * 获取可见时间段的奖项
     * @param mktActivityPrizePOList
     * @return
     */
    List<MktActivityPrizePOWithBLOBs> getShowActivityPrizePOList(List<MktActivityPrizePOWithBLOBs> mktActivityPrizePOList);
}

==> mktcenter-service-20250703-20250703.093321-5-sources.jar: com/bizvane/mktcenterservice/interfaces/ActivityPrizeServiceWX.java <==
package com.bizvane.mktcenterservice.interfaces;

import com.bizvane.mktcenterservice.models.bo.MktActivityPrizeRecordBO;
import com.bizvane.mktcenterservice.models.bo.MktpActivityAwardRecordBO;
import com.bizvane.mktcenterservice.models.po.MktActivityPrizePOWithBLOBs;
import com.bizvane.mktcenterservice.models.po.MktActivityPrizeRecordPO;
import com.bizvane.mktcenterservice.models.vo.ActivityPriceBO;
import com.bizvane.mktcenterservice.models.vo.MktActivityPrizeRecordVO;
import com.bizvane.mktcenterservice.models.vo.ProbabilityVO;
import com.bizvane.mktcenterservice.models.vo.mktp.PrizeRecordCommonRequestVO;
import com.bizvane.utils.responseinfo.ResponseData;

import java.text.ParseException;
import java.util.List;
import java.util.Map;

/**
 * Created by agan on 2018/12/19.
 */
public interface ActivityPrizeServiceWX {
    /**
     * 小程序获取中奖纪录 和中奖纪录轮播
     * @param po
     * @return
     */
    public ResponseData<List<MktActivityPrizeRecordPO>> getPrizeRecordList(MktActivityPrizeRecordPO po);

    /**
     * 小程序获取中奖纪录 和中奖纪录轮播-包含奖项图片
     * @param requestVO
     * @return
     */
    ResponseData<List<MktpActivityAwardRecordBO>> getPrizeRecordListNew(PrizeRecordCommonRequestVO requestVO);

    /**
     * 获取抽奖活动规则
     * @return
     */
    public ResponseData<ActivityPriceBO> selectPrizeList(MktActivityPrizeRecordVO vo);

    /**
     * 执行抽奖活动
     * @param activePriceCode
     * @return
     */
    @Deprecated
    public ResponseData<Map> executeActivityPrize(String activePriceCode, String memberCode) throws ParseException;

    /**
     * 执行抽奖活动(新)
     * @param activePriceCode
     * @param memberCode
     * @return
     * @throws ParseException
     */
    ResponseData<Map> executeActivityPrizeNew(String activePriceCode, String memberCode, Long clientBaseInfoId) throws ParseException;

    public ResponseData<Map<String, Integer>> residueMemberNumber(ProbabilityVO vo) throws ParseException;

    /**
     * 获取可见时间段的奖项
     * @param mktActivityPrizePOList
     * @return
     */
    List<MktActivityPrizePOWithBLOBs> getShowActivityPrizePOList(List<MktActivityPrizePOWithBLOBs> mktActivityPrizePOList);
}
